"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = useMapControl;
exports.mapControlPropTypes = exports.mapControlDefaultProps = void 0;

var _react = require("react");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _mapContext = _interopRequireDefault(require("./map-context"));

var mapControlDefaultProps = {
  captureScroll: false,
  captureDrag: true,
  captureClick: true,
  captureDoubleClick: true,
  capturePointerMove: false
};
exports.mapControlDefaultProps = mapControlDefaultProps;
var mapControlPropTypes = {
  captureScroll: _propTypes["default"].bool,
  captureDrag: _propTypes["default"].bool,
  captureClick: _propTypes["default"].bool,
  captureDoubleClick: _propTypes["default"].bool,
  capturePointerMove: _propTypes["default"].bool
};
exports.mapControlPropTypes = mapControlPropTypes;

function onMount(thisRef) {
  var callbacks = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var ref = thisRef.containerRef.current;
  var eventManager = thisRef.context.eventManager;

  if (!ref || !eventManager) {
    return undefined;
  }

  var events = {
    wheel: function wheel(evt) {
      if (thisRef.props.captureScroll) {
        evt.stopPropagation();
      }

      if (callbacks.onScroll) {
        callbacks.onScroll(evt, thisRef);
      }
    },
    panstart: function panstart(evt) {
      if (thisRef.props.captureDrag) {
        evt.stopPropagation();
      }

      if (callbacks.onDragStart) {
        callbacks.onDragStart(evt, thisRef);
      }
    },
    anyclick: function anyclick(evt) {
      if (thisRef.props.captureClick) {
        evt.stopPropagation();
      }

      if (callbacks.onClick) {
        callbacks.onClick(evt, thisRef);
      }
    },
    click: function click(evt) {
      if (thisRef.props.captureClick) {
        evt.stopPropagation();
      }

      if (callbacks.onClick) {
        callbacks.onClick(evt, thisRef);
      }
    },
    dblclick: function dblclick(evt) {
      if (thisRef.props.captureDoubleClick) {
        evt.stopPropagation();
      }

      if (callbacks.onDoubleClick) {
        callbacks.onDoubleClick(evt, thisRef);
      }
    },
    pointermove: function pointermove(evt) {
      if (thisRef.props.capturePointerMove) {
        evt.stopPropagation();
      }

      if (callbacks.onPointerMove) {
        callbacks.onPointerMove(evt, thisRef);
      }
    }
  };
  eventManager.watch(events, ref);
  return function () {
    eventManager.off(events);
  };
}

function useMapControl(props, callbacks) {
  var context = (0, _react.useContext)(_mapContext["default"]);
  var containerRef = (0, _react.useRef)(null);
  var thisRef = (0, _react.useRef)({
    props: props,
    state: {},
    context: context,
    containerRef: containerRef
  });
  thisRef.current.props = props;
  thisRef.current.context = context;
  (0, _react.useEffect)(function () {
    return onMount(thisRef.current, callbacks);
  }, [context.eventManager]);
  return thisRef.current;
}
//# sourceMappingURL=use-map-control.js.map